Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(72)

Unified Diff: vpython/api/vpython/pep425.proto

Issue 2927573002: [vpython] Fix PEP425 naming. (Closed)
Patch Set: rebase and update Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « vpython/api/vpython/env.pb.go ('k') | vpython/api/vpython/pep425.pb.go » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: vpython/api/vpython/pep425.proto
diff --git a/vpython/api/vpython/pep425.proto b/vpython/api/vpython/pep425.proto
index 803b4565e45522ac3c4f4d9349fa017fb6c04477..c721a80375a218322ca51da37abdd8726d018f90 100644
--- a/vpython/api/vpython/pep425.proto
+++ b/vpython/api/vpython/pep425.proto
@@ -6,13 +6,13 @@ syntax = "proto3";
package vpython;
-// Represnets a Python PEP425 tag.
-message Pep425Tag {
- // Version is the PEP425 version tag (e.g., "cp27").
- string version = 1;
- // ABI is the PEP425 ABI tag (e.g., "cp27mu", "none").
+// Represents a Python PEP425 tag.
+message PEP425Tag {
+ // Python is the PEP425 python tag (e.g., "cp27").
+ string python = 1;
+ // ABI is the PEP425 "python ABI" tag (e.g., "cp27mu", "none").
string abi = 2;
- // Arch is the PEP425 architecture tag (e.g., "linux_x86_64", "armv7l",
- // "any").
- string arch = 3;
+ // Platform is the PEP425 "python platform" tag (e.g., "linux_x86_64",
+ // "armv7l", "any").
+ string platform = 3;
}
« no previous file with comments | « vpython/api/vpython/env.pb.go ('k') | vpython/api/vpython/pep425.pb.go » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698